/****************************************************************************
 *
 *  Rohde & Schwarz RTH Digital Oscilloscope instrument driver include file
 *
 ****************************************************************************/

#ifndef __RSRTH_HEADER
#define __RSRTH_HEADER

#include "rscore.h"
#include "rsrth_attributes.h"
#include "rsrth_utility.h"

#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

//bit - meaning
//-------------
//_0_ - ALIGnment
//1 - Not used
//_2_ - AUToset
//_3_ - WTRIgger
//_4_ - MEASuring
//5 to 15 - Not used
#define RSRTH_VAL_MEASUREMENT_RUNNING_MASK 0x1D
#define RSRTH_VAL_WAIT_FOR_TRIGGER_MASK 0x08

/*****************************************************************************
 *- Useful Macros & Constants -----------------------------------------------*
 *****************************************************************************/
#define RSRTH_SIMULATION_ID_QUERY      "Rohde&Schwarz,RTH,123456/789,1.23"  /* Default definition of ID Query Response for simulation */
#define RSRTH_VALID_ID_RESPONSE_STRING "Rohde&Schwarz"      /* Valid response for identification query */
#define RSRTH_SIMULATION_OPT_QUERY     ""      /* Simulated response for *OPT? command */
#define RSRTH_OPC_TIMEOUT              30000L   /* Maximum time to wait for OPC in milliseconds */

 /****************************************************************************
  *----------------- Instrument Driver Revision Information -----------------*
  ****************************************************************************/

  /* Class Driver Identification */
#define RSRTH_CLASS_DRIVER_DESCRIPTION           ""
#define RSRTH_CLASS_DRIVER_PREFIX                ""
#define RSRTH_CLASS_DRIVER_VENDOR                ""
#define RSRTH_CLASS_DRIVER_REVISION              ""
#define RSRTH_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define RSRTH_CLASS_SPEC_MINOR_VERSION           0L    /* Class specification minor version */

/* Driver Identification */

#define RSRTH_SPECIFIC_DRIVER_DESCRIPTION        ""
#define RSRTH_SPECIFIC_DRIVER_PREFIX             "RSRTH"
#define RSRTH_SPECIFIC_DRIVER_LOCATOR            ""
#define RSRTH_SPECIFIC_DRIVER_VENDOR             ""
#define RSRTH_MAJOR_VERSION                      1L    /* Instrument driver major version          */
#define RSRTH_MINOR_VERSION                      80L    /* Instrument driver minor version          */
#define RSRTH_MINOR_MINOR_VERSION                0L    /* Instrument driver minor minor version    */

/* Driver Capabilities */

#define RSRTH_SUPPORTED_INSTRUMENT_MODELS        "RTH"    /* Instrument driver supported model(s)     */
#define RSRTH_GROUP_CAPABILITIES                 ""
#define RSRTH_FUNCTION_CAPABILITIES              ""

/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/

 /*- Inherent Instrument Specific Attributes ----------------------------*/

     /* User Options */

#define RSRTH_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     /* ViBoolean */
#define RSRTH_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         /* ViBoolean */
#define RSRTH_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        /* ViBoolean */

    /* Driver Identification */

#define RSRTH_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     /* ViString, read-only */
#define RSRTH_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          /* ViString, read-only */
#define RSRTH_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         /* ViString, read-only */
#define RSRTH_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          /* ViString, read-only */
#define RSRTH_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        /* ViString, read-only */
#define RSRTH_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        /* ViInt32,  read-only */
#define RSRTH_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        /* ViInt32,  read-only */

    /* Driver Capabilities */

#define RSRTH_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     /* ViString, read-only */
#define RSRTH_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              /* ViString, read-only */
#define RSRTH_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           /* ViString, read-only */

    /* Driver Setup */

#define RSRTH_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

    /* Instrument Identification */

#define RSRTH_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         /* ViString, read-only */
#define RSRTH_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                /* ViString, read-only */
#define RSRTH_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    /* ViString, read-only */

    /* Advanced Session Information */

#define RSRTH_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          /* ViString, read-only */
#define RSRTH_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME                                    /* ViString, read-only */

    /*- Instrument-Specific Attributes -------------------------------------*/

/* BEGIN GENERATE */
#define RSRTH_ATTR_MODE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2815
#define RSRTH_ATTR_NUM_AVERAGES                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4
#define RSRTH_ATTR_SAMPLE_MODE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 5
#define RSRTH_ATTR_PRESELECTED_RECORD_LENGTH                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2923
#define RSRTH_ATTR_WAVEFORM_UPDATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2924
#define RSRTH_ATTR_HORZ_RECORD_LENGTH                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 8
#define RSRTH_ATTR_HORZ_ADC_SAMPLE_RATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 14
#define RSRTH_ATTR_HORZ_RESOLUTION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 18
#define RSRTH_ATTR_AUTOSCALE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 15
#define RSRTH_ATTR_HORZ_TIME_PER_RECORD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 7
#define RSRTH_ATTR_HORZ_SCALE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 9
#define RSRTH_ATTR_ACQUSITION_START_TIME                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2816
#define RSRTH_ATTR_HORZ_REFERENCE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 17
#define RSRTH_ATTR_CHANNEL_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 25
#define RSRTH_ATTR_VERTICAL_RANGE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 26
#define RSRTH_ATTR_VERTICAL_OFFSET                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 27
#define RSRTH_ATTR_VERTICAL_COUPLING                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 28
#define RSRTH_ATTR_VERTICAL_SCALE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 29
#define RSRTH_ATTR_CHANNEL_OFFSET                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 30
#define RSRTH_ATTR_CHANNEL_BANDWIDTH_LIMIT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 31
#define RSRTH_ATTR_CHANNEL_DELAY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2817
#define RSRTH_ATTR_PROBE_SETTLING                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2925
#define RSRTH_ATTR_PROBE_FACTOR                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2926
#define RSRTH_ATTR_PROBE_UNIT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2927
#define RSRTH_ATTR_INVERT_POLARITY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2928
#define RSRTH_ATTR_WAVEFORM_HEADER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 129
#define RSRTH_ATTR_CHANNEL_THRESHOLD_TECHNOLOGY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2818
#define RSRTH_ATTR_CHANNEL_THRESHOLD_USER                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2819
#define RSRTH_ATTR_CHANNEL_FIND_THRESHOLD                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2820
#define RSRTH_ATTR_CHANNEL_GET_THRESHOLD                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2821
#define RSRTH_ATTR_TRIGGER_TYPE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 37
#define RSRTH_ATTR_TRIGGER_SOURCE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 38
#define RSRTH_ATTR_TRIGGER_MODE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 40
#define RSRTH_ATTR_TRIGGER_NOISE_REJECT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2822
#define RSRTH_ATTR_TRIGGER_LEVEL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 39
#define RSRTH_ATTR_TRIGGER_SLOPE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 45
#define RSRTH_ATTR_EXTERNAL_TRIGGER_LEVEL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 46
#define RSRTH_ATTR_EXTERNAL_TRIGGER_SLOPE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 50
#define RSRTH_ATTR_RUNT_CONDITION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 56
#define RSRTH_ATTR_RUNT_WIDTH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 57
#define RSRTH_ATTR_RUNT_WIDTH_MIN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2823
#define RSRTH_ATTR_RUNT_WIDTH_MAX                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2824
#define RSRTH_ATTR_RUNT_DELTA                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 58
#define RSRTH_ATTR_RUNT_POLARITY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 59
#define RSRTH_ATTR_RUNT_HIGH_THRESHOLD                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 54
#define RSRTH_ATTR_RUNT_LOW_THRESHOLD                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 55
#define RSRTH_ATTR_GLITCH_WIDTH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 60
#define RSRTH_ATTR_GLITCH_POLARITY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 61
#define RSRTH_ATTR_GLITCH_CONDITION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 62
#define RSRTH_ATTR_WIDTH_CONDITION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 63
#define RSRTH_ATTR_WIDTH_WIDTH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 64
#define RSRTH_ATTR_WIDTH_WIDTH_MIN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2825
#define RSRTH_ATTR_WIDTH_WIDTH_MAX                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2826
#define RSRTH_ATTR_WIDTH_DELTA                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 65
#define RSRTH_ATTR_WIDTH_POLARITY                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 66
#define RSRTH_ATTR_WINDOW_CONDITION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 69
#define RSRTH_ATTR_WINDOW_WIDTH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 70
#define RSRTH_ATTR_WINDOW_WIDTH_MIN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2827
#define RSRTH_ATTR_WINDOW_WIDTH_MAX                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2828
#define RSRTH_ATTR_WINDOW_DELTA                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 71
#define RSRTH_ATTR_WINDOW_TIME_CONDITION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 752
#define RSRTH_ATTR_WINDOW_UPPER_LIMIT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 67
#define RSRTH_ATTR_WINDOW_LOWER_LIMIT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 68
#define RSRTH_ATTR_TIMEOUT_CONDITION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 72
#define RSRTH_ATTR_TIMEOUT_VALUE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 73
#define RSRTH_ATTR_INTERVAL_CONDITION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 74
#define RSRTH_ATTR_INTERVAL_WIDTH                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 75
#define RSRTH_ATTR_INTERVAL_WIDTH_MIN                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2829
#define RSRTH_ATTR_INTERVAL_WIDTH_MAX                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2830
#define RSRTH_ATTR_INTERVAL_DELTA                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 76
#define RSRTH_ATTR_INTERVAL_POLARITY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 77
#define RSRTH_ATTR_SLEW_CONDITION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 80
#define RSRTH_ATTR_SLEW_RATE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 81
#define RSRTH_ATTR_SLEW_DELTA                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 82
#define RSRTH_ATTR_SLEW_WIDTH_MIN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2831
#define RSRTH_ATTR_SLEW_WIDTH_MAX                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2832
#define RSRTH_ATTR_SLEW_POLARITY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 83
#define RSRTH_ATTR_SLEW_UPPER_LIMIT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 78
#define RSRTH_ATTR_SLEW_LOWER_LIMIT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 79
#define RSRTH_ATTR_DATA2CLOCK_CONDITION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2833
#define RSRTH_ATTR_DATA2CLOCK_SOURCE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 84
#define RSRTH_ATTR_DATA2CLOCK_DATA_SOURCE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2834
#define RSRTH_ATTR_DATA2CLOCK_HOLD_TIME                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 86
#define RSRTH_ATTR_DATA2CLOCK_SETUP_TIME                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 87
#define RSRTH_ATTR_DATA2CLOCK_POLARITY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 88
#define RSRTH_ATTR_PATTERN_COMBINATION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2835
#define RSRTH_ATTR_PATTERN_TIMEOUT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 91
#define RSRTH_ATTR_PATTERN_CONDITION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 92
#define RSRTH_ATTR_PATTERN_WIDTH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 93
#define RSRTH_ATTR_PATTERN_WIDTH_MIN                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2836
#define RSRTH_ATTR_PATTERN_WIDTH_MAX                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2837
#define RSRTH_ATTR_PATTERN_DELTA                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 94
#define RSRTH_ATTR_PATTERN_CHANNEL_STATE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2838
#define RSRTH_ATTR_SERIAL_PATTERN_SOURCE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 95
#define RSRTH_ATTR_SERIAL_PATTERN_DATA_SOURCE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2839
#define RSRTH_ATTR_SERIAL_PATTERN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 97
#define RSRTH_ATTR_SERIAL_PATTERN_POLARITY                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 98
#define RSRTH_ATTR_SERIAL_PATTERN_FIRST_POLARITY                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2840
#define RSRTH_ATTR_SERIAL_PATTERN_BIT_ORDER                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2841
#define RSRTH_ATTR_TV_TRIGGER_STANDARD                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 689
#define RSRTH_ATTR_TV_TRIGGER_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 690
#define RSRTH_ATTR_TV_TRIGGER_LINE_NUMBER                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 52
#define RSRTH_ATTR_TV_TRIGGER_FIELD                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 691
#define RSRTH_ATTR_TV_TRIGGER_POLARITY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 53
#define RSRTH_ATTR_TV_TRIGGER_PULSE_TYPE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 692
#define RSRTH_ATTR_TV_TRIGGER_LINE_PERIOD                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 693
#define RSRTH_ATTR_TV_TRIGGER_PULSE_WIDTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 694
#define RSRTH_ATTR_TV_TRIGGER_SCAN_MODE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 695
#define RSRTH_ATTR_TRIGGER_SEQUENCE_HOLDOFF_MODE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 116
#define RSRTH_ATTR_TRIGGER_SEQUENCE_HOLDOFF_TIME                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 117
#define RSRTH_ATTR_TRIGGER_SEQUENCE_HOLDOFF_EVENTS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 118
#define RSRTH_ATTR_TRIGGER_SEQUENCE_HOLDOFF_RANDOM_MINIMUM_TIME             RS_SPECIFIC_PUBLIC_ATTR_BASE + 119
#define RSRTH_ATTR_TRIGGER_SEQUENCE_HOLDOFF_RANDOM_MAXIMUM_TIME             RS_SPECIFIC_PUBLIC_ATTR_BASE + 120
#define RSRTH_ATTR_PROTOCOL_I2C_TRIGGER_MODE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353
#define RSRTH_ATTR_PROTOCOL_I2C_TRIGGER_ADRESS_NACK                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 760
#define RSRTH_ATTR_PROTOCOL_I2C_TRIGGER_DATA_WRITE_NACK                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 761
#define RSRTH_ATTR_PROTOCOL_I2C_TRIGGER_DATA_READ_NACK                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 762
#define RSRTH_ATTR_PROTOCOL_I2C_TRIGGER_ACCESS_BIT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357
#define RSRTH_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS_CONDITION                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 551
#define RSRTH_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2842
#define RSRTH_ATTR_PROTOCOL_I2C_TRIGGER_POSITION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2843
#define RSRTH_ATTR_PROTOCOL_I2C_TRIGGER_DATA_CONDITION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 556
#define RSRTH_ATTR_PROTOCOL_I2C_TRIGGER_PATTERN                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2844
#define RSRTH_ATTR_PROTOCOL_SPI_TRIGGER_MODE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 386
#define RSRTH_ATTR_PROTOCOL_SPI_TRIGGER_DATA_PATTERN                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2845
#define RSRTH_ATTR_PROTOCOL_SPI_TRIGGER_DATA_CONDITION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2846
#define RSRTH_ATTR_PROTOCOL_SPI_TRIGGER_POSITION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2847
#define RSRTH_ATTR_PROTOCOL_SPI_TRIGGER_PATTERN_LINE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2848
#define RSRTH_ATTR_PROTOCOL_UART_TRIGGER_MODE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 410
#define RSRTH_ATTR_PROTOCOL_UART_TRIGGER_DATA_PATTERN                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 412
#define RSRTH_ATTR_PROTOCOL_UART_TRIGGER_DATA_PATTERN_CONDITION             RS_SPECIFIC_PUBLIC_ATTR_BASE + 413
#define RSRTH_ATTR_PROTOCOL_LIN_TRIGGER_MODE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 492
#define RSRTH_ATTR_PROTOCOL_LIN_TRIGGER_CONDITION_DATA                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 769
#define RSRTH_ATTR_PROTOCOL_LIN_TRIGGER_PATTERN_DATA                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2849
#define RSRTH_ATTR_PROTOCOL_LIN_TRIGGER_IDENTIFIER_CONDITION                RS_SPECIFIC_PUBLIC_ATTR_BASE + 772
#define RSRTH_ATTR_PROTOCOL_LIN_TRIGGER_PATTERN_IDENTIFIER                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2850
#define RSRTH_ATTR_PROTOCOL_LIN_TRIGGER_CHECKSUM_ERROR                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 775
#define RSRTH_ATTR_PROTOCOL_LIN_TRIGGER_IDENTIFIER_PARITY_ERROR             RS_SPECIFIC_PUBLIC_ATTR_BASE + 776
#define RSRTH_ATTR_PROTOCOL_LIN_TRIGGER_SYNC_ERROR                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 777
#define RSRTH_ATTR_PROTOCOL_CAN_TRIGGER_MODE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 515
#define RSRTH_ATTR_PROTOCOL_CAN_TRIGGER_FRAME_TYPE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 516
#define RSRTH_ATTR_PROTOCOL_CAN_TRIGGER_ID_TYPE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 517
#define RSRTH_ATTR_PROTOCOL_CAN_TRIGGER_FD_BITS_FDF                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2931
#define RSRTH_ATTR_PROTOCOL_CAN_TRIGGER_FD_BITS_BRS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2932
#define RSRTH_ATTR_PROTOCOL_CAN_TRIGGER_FD_BITS_ESI                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2933
#define RSRTH_ATTR_PROTOCOL_CAN_TRIGGER_DATA_CONDITION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 778
#define RSRTH_ATTR_PROTOCOL_CAN_TRIGGER_PATTERN_DATA                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2851
#define RSRTH_ATTR_PROTOCOL_CAN_TRIGGER_BYTE_OFFSET                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2934
#define RSRTH_ATTR_PROTOCOL_CAN_TRIGGER_IDENTIFIER_CONDITION                RS_SPECIFIC_PUBLIC_ATTR_BASE + 781
#define RSRTH_ATTR_PROTOCOL_CAN_TRIGGER_PATTERN_IDENTIFIER                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2852
#define RSRTH_ATTR_PROTOCOL_CAN_TRIGGER_CHECKSUM_ERROR                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 784
#define RSRTH_ATTR_PROTOCOL_CAN_TRIGGER_BIT_STUFFING_ERROR                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 785
#define RSRTH_ATTR_PROTOCOL_CAN_TRIGGER_FORM_ERROR                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 786
#define RSRTH_ATTR_PROTOCOL_CAN_TRIGGER_ACK_ERROR                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 787
#define RSRTH_ATTR_PROTOCOL_CAN_TRIGGER_STUFF_COUNT_ERROR                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2935
#define RSRTH_ATTR_STATE_TRIGGER_CLOCK_SOURCE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2911
#define RSRTH_ATTR_STATE_TRIGGER_CLOCK_EDGE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2912
#define RSRTH_ATTR_STATE_TRIGGER_COMBINATION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2913
#define RSRTH_ATTR_STATE_TRIGGER_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2856
#define RSRTH_ATTR_PROTOCOL_SENT_TRIGGER_TYPE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2936
#define RSRTH_ATTR_PROTOCOL_SENT_TRIGGER_DATA_CONDITION                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2937
#define RSRTH_ATTR_PROTOCOL_SENT_TRIGGER_DATA_PATTERN                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2938
#define RSRTH_ATTR_PROTOCOL_SENT_TRIGGER_IDENTIFIER_CONDITION               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2939
#define RSRTH_ATTR_PROTOCOL_SENT_TRIGGER_IDENTIFIER_PATTERN                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2940
#define RSRTH_ATTR_PROTOCOL_SENT_TRIGGER_STATUS_CONDITION                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2941
#define RSRTH_ATTR_PROTOCOL_SENT_TRIGGER_STATUS_PATTERN                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2942
#define RSRTH_ATTR_PROTOCOL_SENT_TRIGGER_FAST_CRC_ERROR                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2943
#define RSRTH_ATTR_PROTOCOL_SENT_TRIGGER_SLOW_CRC_ERROR                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2944
#define RSRTH_ATTR_PROTOCOL_SENT_TRIGGER_FRAME_LENGTH_ERROR                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2945
#define RSRTH_ATTR_PROTOCOL_SENT_TRIGGER_PULSE_PERIOD_ERROR                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2946
#define RSRTH_ATTR_PROTOCOL_SENT_TRIGGER_SYNC_PULSE_ERROR                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2947
#define RSRTH_ATTR_RUN_NO_WAIT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 131
#define RSRTH_ATTR_RUN                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2915
#define RSRTH_ATTR_STOP                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 132
#define RSRTH_ATTR_CURSOR_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 173
#define RSRTH_ATTR_CURSOR_MEASUREMENT_TYPE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2857
#define RSRTH_ATTR_CURSOR_SOURCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 176
#define RSRTH_ATTR_CURSOR_COUPLING                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2858
#define RSRTH_ATTR_CURSOR_SCALE_COUPLING                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2859
#define RSRTH_ATTR_CURSOR_SET_TO_SCREEN                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2860
#define RSRTH_ATTR_CURSOR_HORIZONTAL_DISTANCE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 816
#define RSRTH_ATTR_CURSOR_VERTICAL_DISTANCE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 817
#define RSRTH_ATTR_CURSOR_INVERSE_DISTANCE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 184
#define RSRTH_ATTR_CURSOR_X_POSITION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 178
#define RSRTH_ATTR_CURSOR_Y_POSITION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 180
#define RSRTH_ATTR_CURSOR_Y_AMPLITUDE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2861
#define RSRTH_ATTR_MEASUREMENT_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 136
#define RSRTH_ATTR_MEASUREMENT_DISABLED_ALL                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 140
#define RSRTH_ATTR_MEASUREMENT_DELAY_SLOPE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2862
#define RSRTH_ATTR_MEASUREMENT_TYPE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2863
#define RSRTH_ATTR_MEASUREMENT_RESULT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2864
#define RSRTH_ATTR_MEASUREMENT_RESULT_LIMIT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2865
#define RSRTH_ATTR_CURSOR_MEASUREMENT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 175
#define RSRTH_ATTR_CURSOR_MEASUREMENT_RESULT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2866
#define RSRTH_ATTR_CURSOR_MEASUREMENT_RESULT_LIMIT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2867
#define RSRTH_ATTR_CURSOR_MEASUREMENT_AMPLITUDE_1                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2909
#define RSRTH_ATTR_CURSOR_MEASUREMENT_AMPLITUDE_2                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2910
#define RSRTH_ATTR_MATH_WAVEFORM_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 235
#define RSRTH_ATTR_MATH_EXPRESSION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 237
#define RSRTH_ATTR_MATH_VERTICAL_RANGE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 238
#define RSRTH_ATTR_MATH_VERTICAL_SCALE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 239
#define RSRTH_ATTR_MATH_VERTICAL_POSITION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 240
#define RSRTH_ATTR_MATH_RESET                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 668
#define RSRTH_ATTR_REFERENCE_WAVEFORM_SOURCE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 270
#define RSRTH_ATTR_REFERENCE_WAVEFORM_DISPLAY_ENABLED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 271
#define RSRTH_ATTR_REFERENCE_WAVEFORM_NAME                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 272
#define RSRTH_ATTR_REFERENCE_WAVEFORM_LOAD                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 273
#define RSRTH_ATTR_REFERENCE_WAVEFORM_SAVE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 274
#define RSRTH_ATTR_REFERENCE_WAVEFORM_DELETE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 275
#define RSRTH_ATTR_REFERENCE_WAVEFORM_UPDATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 276
#define RSRTH_ATTR_REFERENCE_WAVEFORM_VERTICAL_POSITION                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 282
#define RSRTH_ATTR_MASK_TEST_VIOLATION_EVENT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2868
#define RSRTH_ATTR_MASK_TEST_STATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2869
#define RSRTH_ATTR_MASK_TEST_RESET                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2870
#define RSRTH_ATTR_MASK_TEST_DURATION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2872
#define RSRTH_ATTR_MASK_TEST_CREATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2873
#define RSRTH_ATTR_MASK_TEST_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2874
#define RSRTH_ATTR_MASK_TEST_VERTICAL_WIDTH                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2875
#define RSRTH_ATTR_MASK_TEST_HORIZONTAL_WIDTH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2876
#define RSRTH_ATTR_MASK_TEST_RESULT_TOTAL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2877
#define RSRTH_ATTR_MASK_TEST_RESULT_PASSED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2878
#define RSRTH_ATTR_MASK_TEST_RESULT_PASSED_PCT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2879
#define RSRTH_ATTR_MASK_TEST_RESULT_FAILED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2880
#define RSRTH_ATTR_MASK_TEST_RESULT_FAILED_PCT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2881
#define RSRTH_ATTR_LOGIC_CHANNEL_STATE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2882
#define RSRTH_ATTR_LOGIC_CHANNEL_COUPLING                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2883
#define RSRTH_ATTR_PROBE_STATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2884
#define RSRTH_ATTR_LOGIC_CHANNEL_DESKEW                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2885
#define RSRTH_ATTR_LOGIC_CHANNEL_GROUP_THRESHOLD_TECHNOLOGY                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2886
#define RSRTH_ATTR_LOGIC_CHANNEL_GROUP_THRESHOLD                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2887
#define RSRTH_ATTR_LOGIC_CHANNEL_GROUP_GET_THRESHOLD                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2888
#define RSRTH_ATTR_LOGIC_CHANNEL_GROUP_HYSTERESIS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2908
#define RSRTH_ATTR_WLAN_MODE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2889
#define RSRTH_ATTR_HISTORY_GET_ACQUISITIONS_COUNT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 562
#define RSRTH_ATTR_HISTORY_STATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 534
#define RSRTH_ATTR_HISTORY_STOP_INDEX                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 536
#define RSRTH_ATTR_HISTORY_START_INDEX                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 535
#define RSRTH_ATTR_HISTORY_ACQUISITION_VIEW                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 537
#define RSRTH_ATTR_HISTORY_PLAYER_SPEED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2890
#define RSRTH_ATTR_HISTORY_NUMBER_OF_SEGMENTS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2891
#define RSRTH_ATTR_HISTORY_PLAYBACK                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 540
#define RSRTH_ATTR_HISTORY_AUTO_REPEAT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 539
#define RSRTH_ATTR_HISTORY_ABSOLUTE_TIME_STAMP                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1278
#define RSRTH_ATTR_HISTORY_RELATIVE_TIME_STAMP                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1279
#define RSRTH_ATTR_HISTORY_DATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 542
#define RSRTH_ATTR_DISPLAY_CONTRAST_MODE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2892
#define RSRTH_ATTR_DISPLAY_LCD_STATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2893
#define RSRTH_ATTR_DISPLAY_TOUCH_SCREEN_STATE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2894
#define RSRTH_ATTR_DISPLAY_PERSISTENCE_TIME                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 424
#define RSRTH_ATTR_DISPLAY_PERSISTENCE_TYPE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2895
#define RSRTH_ATTR_ZOOM_STATE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2896
#define RSRTH_ATTR_ZOOM_SCALE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2897
#define RSRTH_ATTR_ZOOM_POSITION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2898
#define RSRTH_ATTR_CURRENT_DIRECTORY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 299
#define RSRTH_ATTR_CREATE_DIRECTORY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 300
#define RSRTH_ATTR_REMOVE_DIRECTORY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 301
#define RSRTH_ATTR_DELETE_FILE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 302
#define RSRTH_ATTR_RECALL_INSTRUMENT_SETTINGS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2901
#define RSRTH_ATTR_SAVE_INSTRUMENT_SETTINGS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2902
#define RSRTH_ATTR_WAVEFORM_EXPORT_MULTICHANNEL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 742
#define RSRTH_ATTR_WAVEFORM_EXPORT_SOURCE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 563
#define RSRTH_ATTR_WAVEFORM_EXPORT_DATA_LOGGING                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 569
#define RSRTH_ATTR_WAVEFORM_EXPORT_FILE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 570
#define RSRTH_ATTR_WAVEFORM_EXPORT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 571
#define RSRTH_ATTR_WAVEFORM_EXPORT_INTERLEAVED_XY                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 699
#define RSRTH_ATTR_HARDCOPY_FILE_NAME                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 303
#define RSRTH_ATTR_HARDCOPY_PRINT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2903
#define RSRTH_ATTR_HARDCOPY_BWCOLOR                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 454
#define RSRTH_ATTR_HARDCOPY_INVERSE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2948
#define RSRTH_ATTR_HARDCOPY_LANGUAGE_OUTPUT_FORMAT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 456
#define RSRTH_ATTR_APP_PATH                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2949
#define RSRTH_ATTR_APP_PERSISTENCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2950
#define RSRTH_ATTR_ID_QUERY_RESPONSE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 304
#define RSRTH_ATTR_LOGGING                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2648
#define RSRTH_ATTR_BYTE_ORDER                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2154
#define RSRTH_ATTR_SYSTEM_ERROR                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2914
#define RSRTH_ATTR_PROCESS_ALL_PREVIOUS_COMMANDS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2167

// RsRth_rngSampleMode
#define RSRTH_VAL_SAMPLE                                                    0
#define RSRTH_VAL_PDET                                                      1
#define RSRTH_VAL_HRES                                                      2
#define RSRTH_VAL_AVER                                                      3
#define RSRTH_VAL_ENV                                                       4

// RsRth_rngVerticalCoupling
#define RSRTH_VAL_ACL                                                       0
#define RSRTH_VAL_DCL                                                       1

// RsRth_rngChannelBWLimit
#define RSRTH_VAL_BW_FULL                                                   0
#define RSRTH_VAL_BW_350                                                    1
#define RSRTH_VAL_BW_200                                                    2
#define RSRTH_VAL_BW_100                                                    3
#define RSRTH_VAL_BW_60                                                     4
#define RSRTH_VAL_BW_50                                                     5
#define RSRTH_VAL_BW_40                                                     6
#define RSRTH_VAL_BW_20                                                     7
#define RSRTH_VAL_BW_10                                                     8
#define RSRTH_VAL_BW_5                                                      9
#define RSRTH_VAL_BW_4                                                      10
#define RSRTH_VAL_BW_2                                                      11
#define RSRTH_VAL_BW_1                                                      12
#define RSRTH_VAL_BW_B5HK                                                   13
#define RSRTH_VAL_BW_B4HK                                                   14
#define RSRTH_VAL_BW_B2HK                                                   15
#define RSRTH_VAL_BW_B1HK                                                   16
#define RSRTH_VAL_BW_B50K                                                   17
#define RSRTH_VAL_BW_B40K                                                   18
#define RSRTH_VAL_BW_B20K                                                   19
#define RSRTH_VAL_BW_B10K                                                   20
#define RSRTH_VAL_BW_B5K                                                    21
#define RSRTH_VAL_BW_B4K                                                    22
#define RSRTH_VAL_BW_B2K                                                    23
#define RSRTH_VAL_BW_B1K                                                    24

// RsRth_rngTriggerMode
#define RSRTH_VAL_NORMAL                                                    0
#define RSRTH_VAL_AUTO                                                      1
#define RSRTH_VAL_SINGLE                                                    2

// RsRth_rngTriggerType
#define RSRTH_VAL_TRIGGER_EDGE                                              0
#define RSRTH_VAL_TRIGGER_WIDTH                                             1
#define RSRTH_VAL_TRIGGER_RUNT                                              2
#define RSRTH_VAL_TRIGGER_GLITCH                                            3
#define RSRTH_VAL_TRIGGER_WINDOW                                            4
#define RSRTH_VAL_TRIGGER_TIMEOUT                                           5
#define RSRTH_VAL_TRIGGER_INTERVAL                                          6
#define RSRTH_VAL_TRIGGER_SLEW_RATE                                         7
#define RSRTH_VAL_TRIGGER_DATA_TO_CLOCK                                     8
#define RSRTH_VAL_TRIGGER_PATTERN                                           9
#define RSRTH_VAL_TRIGGER_SERIAL_PATTERN                                    11
#define RSRTH_VAL_TRIGGER_STATE                                             12
#define RSRTH_VAL_TRIGGER_TV                                                14
#define RSRTH_VAL_TRIGGER_PROTOCOL                                          10

// RsRth_rngWidthCondition
#define RSRTH_VAL_SHORTER                                                   0
#define RSRTH_VAL_LONGER                                                    1
#define RSRTH_VAL_WITHIN                                                    2
#define RSRTH_VAL_OUTSIDE                                                   3
#define RSRTH_VAL_NOTEQUAL                                                  4
#define RSRTH_VAL_EQUAL                                                     5

// RsRth_rngWindowCondition
#define RSRTH_VAL_ENTER                                                     0
#define RSRTH_VAL_EXIT                                                      1

// RsRth_rngTimeoutCondition
#define RSRTH_VAL_TIMEOUT_LOW                                               0
#define RSRTH_VAL_TIMEOUT_HIGH                                              1
#define RSRTH_VAL_TIMEOUT_EITHER                                            2

// RsRth_rngProtocolI2CTriggerType
#define RSRTH_VAL_I2C_TRIGGER_START                                         0
#define RSRTH_VAL_I2C_TRIGGER_RESTART                                       1
#define RSRTH_VAL_I2C_TRIGGER_STOP                                          2
#define RSRTH_VAL_I2C_TRIGGER_NACK                                          3
#define RSRTH_VAL_I2C_TRIGGER_ADDRESS                                       4
#define RSRTH_VAL_I2C_TRIGGER_DATA                                          5
#define RSRTH_VAL_I2C_TRIGGER_ADAT                                          6

// RsRth_rngProtocolI2CAccessBit
#define RSRTH_VAL_I2C_ACCESS_BIT_EITHER                                     0
#define RSRTH_VAL_I2C_ACCESS_BIT_READ                                       1
#define RSRTH_VAL_I2C_ACCESS_BIT_WRITE                                      2

// RsRth_rngProtocolUARTTriggerType
#define RSRTH_VAL_UART_TRIGGER_STBT                                         0
#define RSRTH_VAL_UART_TRIGGER_PCKS                                         1
#define RSRTH_VAL_UART_TRIGGER_DATA                                         2
#define RSRTH_VAL_UART_TRIGGER_PRER                                         3
#define RSRTH_VAL_UART_TRIGGER_BRKC                                         4
#define RSRTH_VAL_UART_TRIGGER_FERR                                         5

// RsRth_rngProtocolLINTrigger
#define RSRTH_VAL_LIN_SYNC                                                  0
#define RSRTH_VAL_LIN_FRAME_ID                                              1
#define RSRTH_VAL_LIN_FRAME_ID_DATA                                         2
#define RSRTH_VAL_LIN_FRAME_WAKEUP                                          3
#define RSRTH_VAL_LIN_ERR_COND                                              4

// RsRth_rngProtocolCANTriggMode
#define RSRTH_VAL_CAN_FRAME_START                                           0
#define RSRTH_VAL_CAN_FRAME_TYPE                                            1
#define RSRTH_VAL_CAN_MSG_ID                                                2
#define RSRTH_VAL_CAN_MSG_ID_DATA                                           3
#define RSRTH_VAL_CAN_ERR_COND                                              4
#define RSRTH_VAL_CAN_FRAME_EOF                                             5

// RsRth_rngProtocolCANIDType
#define RSRTH_VAL_CAN_FRAME_ID_TYPE_B11                                     0
#define RSRTH_VAL_CAN_FRAME_ID_TYPE_B29                                     1
#define RSRTH_VAL_CAN_FRAME_ID_TYPE_ANY                                     2

// RsRth_rngHardcopyLang
#define RSRTH_VAL_HARDCOPY_LANG_PNG                                         0
#define RSRTH_VAL_HARDCOPY_LANG_JPG                                         1
#define RSRTH_VAL_HARDCOPY_LANG_BMP                                         2
#define RSRTH_VAL_HARDCOPY_LANG_TIFF                                        3

// RsRth_rngTVTriggerStandard
#define RSRTH_VAL_TV_STANDARD_CUSTOM                                        0
#define RSRTH_VAL_TV_STANDARD_PAL                                           1
#define RSRTH_VAL_TV_STANDARD_PALM                                          2
#define RSRTH_VAL_TV_STANDARD_NTSC                                          3
#define RSRTH_VAL_TV_STANDARD_SEC                                           4
#define RSRTH_VAL_TV_STANDARD_P480L60HZ                                     5
#define RSRTH_VAL_TV_STANDARD_P720L30HZ                                     6
#define RSRTH_VAL_TV_STANDARD_P720L50HZ                                     7
#define RSRTH_VAL_TV_STANDARD_P720L60HZ                                     8
#define RSRTH_VAL_TV_STANDARD_I1080L50HZ                                    9
#define RSRTH_VAL_TV_STANDARD_I1080L60HZ                                    10
#define RSRTH_VAL_TV_STANDARD_P1080L24HZ                                    11
#define RSRTH_VAL_TV_STANDARD_P1080L24HZSF                                  12
#define RSRTH_VAL_TV_STANDARD_P1080L25HZ                                    13
#define RSRTH_VAL_TV_STANDARD_P1080L30HZ                                    14
#define RSRTH_VAL_TV_STANDARD_P1080L50HZ                                    15
#define RSRTH_VAL_TV_STANDARD_P1080L60HZ                                    16
#define RSRTH_VAL_TV_STANDARD_P576L50HZ                                     17

// RSRth_rngTVTriggerMode
#define RSRTH_VAL_TV_MODE_ALL                                               0
#define RSRTH_VAL_TV_MODE_ODD                                               1
#define RSRTH_VAL_TV_MODE_EVEN                                              2
#define RSRTH_VAL_TV_MODE_ALIN                                              3
#define RSRTH_VAL_TV_MODE_LINE                                              4

// RsRth_rngTVTriggerField
#define RSRTH_VAL_TV_FIELD_ODD                                              0
#define RSRTH_VAL_TV_FIELD_EVEN                                             1

// RsRth_rngTVTriggerPulseType
#define RSRTH_VAL_TV_PULSE_BI_LEVEL                                         0
#define RSRTH_VAL_TV_PULSE_TRI_LEVEL                                        1

// RsRth_rngTVScanMode
#define RSRTH_VAL_TV_SCAN_MODE_INTERLACED                                   0
#define RSRTH_VAL_TV_SCAN_MODE_PROGRESSIVE                                  1
#define RSRTH_VAL_TV_SCAN_MODE_SEGMENTED                                    2

// RsRth_rngByteOrder
#define RSRTH_VAL_MSBF                                                      0
#define RSRTH_VAL_LSBF                                                      1

// RsRth_rngHistoryPlayerSpeed
#define RSRTH_VAL_TPAC_AUTO                                                 0
#define RSRTH_VAL_TPAC_SLOW                                                 1
#define RSRTH_VAL_TPAC_MEDIUM                                               2
#define RSRTH_VAL_TPAC_FAST                                                 3

// RsRth_rngHistoryNumberofSegments
#define RSRTH_VAL_LOW                                                       0
#define RSRTH_VAL_MEDIUM                                                    1
#define RSRTH_VAL_HIGH                                                      2

// RsRth_rngChannelThresholdTechnology
#define RSRTH_VAL_THR_USER                                                  0
#define RSRTH_VAL_THR_TTL                                                   1
#define RSRTH_VAL_THR_ECL                                                   2
#define RSRTH_VAL_THR_CMOS                                                  3
#define RSRTH_VAL_THR_GND                                                   4
#define RSRTH_VAL_THR_CAN                                                   5
#define RSRTH_VAL_THR_LIN7V                                                 6
#define RSRTH_VAL_THR_LIN12V                                                7
#define RSRTH_VAL_THR_LIN18V                                                8

// RsRth_rngCursorFunction
#define RSRTH_VAL_CURSOR_HORIZONTAL                                         0
#define RSRTH_VAL_CURSOR_VERTICAL                                           1
#define RSRTH_VAL_CURSOR_TRACKING                                           2
#define RSRTH_VAL_CURSOR_MEASURE                                            3

// RsRth_rngLimitType
#define RSRTH_VAL_INSIDE_LIMIT                                              0
#define RSRTH_VAL_OVER_LIMIT                                                1
#define RSRTH_VAL_UNDER_LIMIT                                               2
#define RSRTH_VAL_OUTSIDE_LIMIT                                             3

// RsRth_rngDisplayPersistenceType
#define RSRTH_VAL_PERSISTENCE_OFF                                           0
#define RSRTH_VAL_PERSISTENCE_TIME                                          1
#define RSRTH_VAL_PERSISTENCE_INF                                           2

// RsRth_rngMaskTestViolationEvent
#define RSRTH_VAL_MASK_TEST_EVENT_NONE                                      0
#define RSRTH_VAL_MASK_TEST_EVENT_STOP                                      1
#define RSRTH_VAL_MASK_TEST_EVENT_BEEP                                      2
#define RSRTH_VAL_MASK_TEST_EVENT_BPSTOP                                    3

// RsRth_rngMaskTestState
#define RSRTH_VAL_STATE_NOMASK                                              0
#define RSRTH_VAL_STATE_RUNNING                                             1
#define RSRTH_VAL_STATE_IDLE                                                2

// RsRth_rngMeasurementDelaySlope
#define RSRTH_VAL_MEAS_NEG                                                  0
#define RSRTH_VAL_MEAS_POS                                                  1
#define RSRTH_VAL_MEAS_EITHER                                               2

// RsRth_rngDataWaveformSource
#define RSRTH_VAL_DATA_C1                                                   1
#define RSRTH_VAL_DATA_C2                                                   2
#define RSRTH_VAL_DATA_C3                                                   3
#define RSRTH_VAL_DATA_C4                                                   4
#define RSRTH_VAL_DATA_M1                                                   5
#define RSRTH_VAL_DATA_D0                                                   8
#define RSRTH_VAL_DATA_D1                                                   9
#define RSRTH_VAL_DATA_D2                                                   10
#define RSRTH_VAL_DATA_D3                                                   11
#define RSRTH_VAL_DATA_D4                                                   12
#define RSRTH_VAL_DATA_D5                                                   13
#define RSRTH_VAL_DATA_D6                                                   14
#define RSRTH_VAL_DATA_D7                                                   15
#define RSRTH_VAL_DATA_R                                                    6

// RsRth_rngMeasurement
#define RSRTH_VAL_MEAS_PERIOD                                               0
#define RSRTH_VAL_MEAS_FREQ                                                 1
#define RSRTH_VAL_MEAS_RTIME                                                2
#define RSRTH_VAL_MEAS_FTIME                                                3
#define RSRTH_VAL_MEAS_PPULSE                                               4
#define RSRTH_VAL_MEAS_NPULSE                                               5
#define RSRTH_VAL_MEAS_PDCYCLE                                              6
#define RSRTH_VAL_MEAS_NDCYCLE                                              7
#define RSRTH_VAL_MEAS_MEAN                                                 10
#define RSRTH_VAL_MEAS_RMS                                                  11
#define RSRTH_VAL_MEAS_CREST                                                12
#define RSRTH_VAL_MEAS_STDDEV                                               13
#define RSRTH_VAL_MEAS_MIN                                                  14
#define RSRTH_VAL_MEAS_MAX                                                  15
#define RSRTH_VAL_MEAS_PKPK                                                 16
#define RSRTH_VAL_MEAS_BASELEV                                              17
#define RSRTH_VAL_MEAS_TOPLEV                                               18
#define RSRTH_VAL_MEAS_AMPL                                                 19
#define RSRTH_VAL_MEAS_OVERSHOOT                                            20
#define RSRTH_VAL_MEAS_PRESHOOT                                             21
#define RSRTH_VAL_MEAS_AC                                                   22
#define RSRTH_VAL_MEAS_DC                                                   23
#define RSRTH_VAL_MEAS_ACDC                                                 24
#define RSRTH_VAL_MEAS_PPC                                                  25
#define RSRTH_VAL_MEAS_NPC                                                  26
#define RSRTH_VAL_MEAS_RECOUNT                                              27
#define RSRTH_VAL_MEAS_FECOUNT                                              28
#define RSRTH_VAL_MEAS_PWRP                                                 29
#define RSRTH_VAL_MEAS_PWRS                                                 30
#define RSRTH_VAL_MEAS_PWRQ                                                 31
#define RSRTH_VAL_MEAS_PWRF                                                 32
#define RSRTH_VAL_MEAS_DELAY                                                8
#define RSRTH_VAL_MEAS_PHASE                                                9

// RsRth_rngMode
#define RSRTH_VAL_MODE_SCOPE                                                0
#define RSRTH_VAL_MODE_XY                                                   1
#define RSRTH_VAL_MODE_MASK                                                 2
#define RSRTH_VAL_MODE_ROLL                                                 3
#define RSRTH_VAL_MODE_METER                                                4
#define RSRTH_VAL_MODE_FFT                                                  5
#define RSRTH_VAL_MODE_LOGGER                                               6
#define RSRTH_VAL_MODE_COUNTER                                              7
#define RSRTH_VAL_MODE_PROTOCOL                                             8
#define RSRTH_VAL_MODE_HARMONIC                                             9
#define RSRTH_VAL_MODE_SPECTRUM                                             10

// RsRth_rngWLANMode
#define RSRTH_VAL_WLAN_ACCESSPOINT                                          0
#define RSRTH_VAL_WLAN_CLIENT                                               1

// RsRth_rngNqEq
#define RSRTH_VAL_NQ                                                        0
#define RSRTH_VAL_EQ                                                        1

// RsRth_rngProtocolCANTriggFrameType
#define RSRTH_VAL_CAN_FRAME_TYPE_DATA                                       0
#define RSRTH_VAL_CAN_FRAME_TYPE_REMOTE                                     1
#define RSRTH_VAL_CAN_FRAME_TYPE_ERROR                                      2
#define RSRTH_VAL_CAN_FRAME_TYPE_OVER_LOAD                                  3
#define RSRTH_VAL_CAN_FRAME_TYPE_DOR                                        4

// RsRth_rngProtocolData2ClockCondition
#define RSRTH_VAL_COND_OK                                                   0
#define RSRTH_VAL_COND_VIOL                                                 1

// RsRth_rngTriggerPolarity
#define RSRTH_VAL_POSITIVE                                                  0
#define RSRTH_VAL_NEGATIVE                                                  1
#define RSRTH_VAL_EITHER                                                    2

// RsRth_rngHoldoffMode
#define RSRTH_VAL_HOLDOFF_OFF                                               0
#define RSRTH_VAL_HOLDOFF_TIME                                              1
#define RSRTH_VAL_HOLDOFF_EVENTS                                            2
#define RSRTH_VAL_HOLDOFF_RANDOM                                            3

// RsRth_rngTriggerState
#define RSRTH_VAL_TRIGGER_ZERO                                              0
#define RSRTH_VAL_TRIGGER_ONE                                               1
#define RSRTH_VAL_TRIGGER_DONT                                              2

// RsRth_rngLogic
#define RSRTH_VAL_AND                                                       0
#define RSRTH_VAL_OR                                                        1

// RsRth_rngPatternCondition
#define RSRTH_VAL_TIMEOUT                                                   6
#define RSRTH_VAL_ANY                                                       7

// RsRth_rngBitOrder
#define RSRTH_VAL_BIT_MSBF                                                  0
#define RSRTH_VAL_BIT_LSBF                                                  1

// RsRth_rngProtocolSPITriggerMode
#define RSRTH_VAL_SPI_FSTART                                                0
#define RSRTH_VAL_SPI_FEND                                                  1
#define RSRTH_VAL_SPI_DATA                                                  2

// RsRth_rngProtocolSPITriggerPatternLine
#define RSRTH_VAL_SPI_LINE_MISO                                             0
#define RSRTH_VAL_SPI_LINE_MOSI                                             1

// RsRth_rngLogicChannelGroupHysteresis
#define RSRTH_VAL_LOGIC_HYST_SMALL                                          0
#define RSRTH_VAL_LOGIC_HYST_MEDIUM                                         1
#define RSRTH_VAL_LOGIC_HYST_LARGE                                          2

// RsRth_rngPreselectedRecordLength
#define RSRTH_VAL_PRESELECTED_RECORD_LENGTH_MAX                             0
#define RSRTH_VAL_PRESELECTED_RECORD_LENGTH_MIDDLE                          1
#define RSRTH_VAL_PRESELECTED_RECORD_LENGTH_MIN                             2

// RsRth_rngWaveformUpdate
#define RSRTH_VAL_WAVEFORM_UPDATE_INTERMEDIATE                              0
#define RSRTH_VAL_WAVEFORM_UPDATE_FULL                                      1

// RsRth_rngProbeSettling
#define RSRTH_VAL_PROBE_SETTLING_V1TO1                                      0
#define RSRTH_VAL_PROBE_SETTLING_V10TO1                                     1
#define RSRTH_VAL_PROBE_SETTLING_V20TO1                                     2
#define RSRTH_VAL_PROBE_SETTLING_V100TO1                                    3
#define RSRTH_VAL_PROBE_SETTLING_V200TO1                                    4
#define RSRTH_VAL_PROBE_SETTLING_V1000TO1                                   5
#define RSRTH_VAL_PROBE_SETTLING_C100V1A                                    6
#define RSRTH_VAL_PROBE_SETTLING_C10V1A                                     7
#define RSRTH_VAL_PROBE_SETTLING_C1V1A                                      8
#define RSRTH_VAL_PROBE_SETTLING_C100MV1A                                   9
#define RSRTH_VAL_PROBE_SETTLING_C10MV1A                                    10
#define RSRTH_VAL_PROBE_SETTLING_C1MV1A                                     11
#define RSRTH_VAL_PROBE_SETTLING_T1MVC                                      12
#define RSRTH_VAL_PROBE_SETTLING_T1MVF                                      13
#define RSRTH_VAL_PROBE_SETTLING_TPTC                                       14
#define RSRTH_VAL_PROBE_SETTLING_TPTF                                       15
#define RSRTH_VAL_PROBE_SETTLING_USER                                       16

// RsRth_rngProbeUnit
#define RSRTH_VAL_PROBE_UNIT_V                                              0
#define RSRTH_VAL_PROBE_UNIT_A                                              1

// RsRth_rngInvert
#define RSRTH_VAL_POLARITY_NORMAL                                           0
#define RSRTH_VAL_POLARITY_INVERTED                                         1

// RsRth_rngCANFDBits
#define RSRTH_VAL_CAN_FD_BITS_ZERO                                          0
#define RSRTH_VAL_CAN_FD_BITS_ONE                                           1
#define RSRTH_VAL_CAN_FD_BITS_DC                                            2

// RsRth_rngProtocolSENTTriggerType
#define RSRTH_VAL_SENT_START_OF_FRAME                                       0
#define RSRTH_VAL_SENT_FAST_STATUS                                          1
#define RSRTH_VAL_SENT_FAST_STATUS_AND_DATA                                 2
#define RSRTH_VAL_SENT_SLOW_IDENTIFIER                                      3
#define RSRTH_VAL_SENT_SLOW_IDENTIFIER_AND_DATA                             4
#define RSRTH_VAL_SENT_ERROR_CONDITION                                      5

// RsRth_rngProtocolSENTTriggerCondition
#define RSRTH_VAL_LTHAN                                                     0
#define RSRTH_VAL_GTHAN                                                     1
#define RSRTH_VAL_IN_RANGE                                                  2
#define RSRTH_VAL_OUT_OF_RANGE                                              3
#define RSRTH_VAL_NOT_EQUAL                                                 4
#define RSRTH_VAL_LETHAN                                                    6
#define RSRTH_VAL_GETHAN                                                    7
#define RSRTH_VAL_UNUSED                                                    8

//repcap Channel
#define RSRTH_REPCAP_CHANNEL_CH1                                            1
#define RSRTH_REPCAP_CHANNEL_CH2                                            2
#define RSRTH_REPCAP_CHANNEL_CH3                                            3
#define RSRTH_REPCAP_CHANNEL_CH4                                            4

//repcap CPosition
#define RSRTH_REPCAP_CPOSITION_P1                                           1
#define RSRTH_REPCAP_CPOSITION_P2                                           2

//repcap TriggerChannel
#define RSRTH_REPCAP_TRIGGERCHANNEL_TCH1                                    1
#define RSRTH_REPCAP_TRIGGERCHANNEL_TCH2                                    2
#define RSRTH_REPCAP_TRIGGERCHANNEL_TCH3                                    3
#define RSRTH_REPCAP_TRIGGERCHANNEL_TCH4                                    4

//repcap Measurement
#define RSRTH_REPCAP_MEASUREMENT_M1                                         1
#define RSRTH_REPCAP_MEASUREMENT_M2                                         2
#define RSRTH_REPCAP_MEASUREMENT_M3                                         3
#define RSRTH_REPCAP_MEASUREMENT_M4                                         4

//repcap LogicChannel
#define RSRTH_REPCAP_LOGICCHANNEL_LCH1                                      1
#define RSRTH_REPCAP_LOGICCHANNEL_LCH2                                      2
#define RSRTH_REPCAP_LOGICCHANNEL_LCH3                                      3
#define RSRTH_REPCAP_LOGICCHANNEL_LCH4                                      4
#define RSRTH_REPCAP_LOGICCHANNEL_LCH5                                      5
#define RSRTH_REPCAP_LOGICCHANNEL_LCH6                                      6
#define RSRTH_REPCAP_LOGICCHANNEL_LCH7                                      7
#define RSRTH_REPCAP_LOGICCHANNEL_LCH8                                      8
#define RSRTH_REPCAP_LOGICCHANNEL_LCH9                                      9

//repcap LCHGroup
#define RSRTH_REPCAP_LCHGROUP_LCHG1                                         1
#define RSRTH_REPCAP_LCHGROUP_LCHG2                                         2
#define RSRTH_REPCAP_LCHGROUP_LCHG3                                         3

//repcap TriggerSourceExt
#define RSRTH_REPCAP_TRIGGERSOURCEEXT_ACH1                                  1
#define RSRTH_REPCAP_TRIGGERSOURCEEXT_ACH2                                  2
#define RSRTH_REPCAP_TRIGGERSOURCEEXT_ACH3                                  3
#define RSRTH_REPCAP_TRIGGERSOURCEEXT_ACH4                                  4
#define RSRTH_REPCAP_TRIGGERSOURCEEXT_DCH0                                  5
#define RSRTH_REPCAP_TRIGGERSOURCEEXT_DCH1                                  6
#define RSRTH_REPCAP_TRIGGERSOURCEEXT_DCH2                                  7
#define RSRTH_REPCAP_TRIGGERSOURCEEXT_DCH3                                  8
#define RSRTH_REPCAP_TRIGGERSOURCEEXT_DCH4                                  9
#define RSRTH_REPCAP_TRIGGERSOURCEEXT_DCH5                                  10
#define RSRTH_REPCAP_TRIGGERSOURCEEXT_DCH6                                  11
#define RSRTH_REPCAP_TRIGGERSOURCEEXT_DCH7                                  12
/* END GENERATE */

/*****************************************************************************
 *- Hidden Attribute Declarations -------------------------------------------*
 *****************************************************************************/

#define RSRTH_ATTR_OPC_TIMEOUT               (RS_ATTR_OPC_TIMEOUT)           /* ViInt32 */
#define RSRTH_ATTR_IO_SESSION                (RS_ATTR_IO_SESSION)            /* ViSession */
#define RSRTH_ATTR_OPC_CALLBACK              (RS_ATTR_OPC_CALLBACK)          /* ViAddr */
#define RSRTH_ATTR_CHECK_STATUS_CALLBACK     (RS_ATTR_CHECK_STATUS_CALLBACK) /* ViAddr */

 /****************************************************************************
  *---------------- Constant definition  ------------------------------------*
  ****************************************************************************/
#define RSRTH_VAL_CHANNEL_1   1
#define RSRTH_VAL_CHANNEL_2   2
#define RSRTH_VAL_CHANNEL_3   3
#define RSRTH_VAL_CHANNEL_4   4

#define RSRTH_VAL_TS_ABS 0
#define RSRTH_VAL_TS_REL 1

#define RSRTH_VAL_MEASUREMENT_1 1
#define RSRTH_VAL_MEASUREMENT_2 2
#define RSRTH_VAL_MEASUREMENT_3 3
#define RSRTH_VAL_MEASUREMENT_4 4

#define RSRTH_VAL_WAV_SELECT 0
#define RSRTH_VAL_WAV_OPEN   1
#define RSRTH_VAL_WAV_SAVE   2
#define RSRTH_VAL_WAV_DELETE 3

#define RSRTH_VAL_CHANNEL1 1
#define RSRTH_VAL_CHANNEL2 2
#define RSRTH_VAL_CHANNEL3 3
#define RSRTH_VAL_CHANNEL4 4
#define RSRTH_VAL_D0 8
#define RSRTH_VAL_D1 9
#define RSRTH_VAL_D2 10
#define RSRTH_VAL_D3 11
#define RSRTH_VAL_D4 12
#define RSRTH_VAL_D5 13
#define RSRTH_VAL_D6 14
#define RSRTH_VAL_D7 15

#define RSRTH_VAL_FAST_SWEEP_NORMAL 0
#define RSRTH_VAL_FAST_SWEEP_FAST   1

#define RSRTH_VAL_FILE_COPY    0
#define RSRTH_VAL_FILE_MOVE    1
#define RSRTH_VAL_FILE_DELETE  2
#define RSRTH_VAL_FILE_NEW_DIR 3
#define RSRTH_VAL_FILE_CDIR    4
#define RSRTH_VAL_FILE_RDIR    5

#define RSRTH_VAL_ACQ_MODE_SINGLE     0
#define RSRTH_VAL_ACQ_MODE_CONTINUOUS 1

  /***************************************************************************
  *---------------- Instrument Driver Function Declarations -----------------*
   ****************************************************************************/
ViStatus rsrth_init(ViRsrc     resourceName,
                    ViBoolean  IDQuery,
                    ViBoolean  resetDevice,
                    ViSession* instrSession);

ViStatus rsrth_InitWithOptions(ViRsrc     resourceName,
                               ViBoolean  IDQuery,
                               ViBoolean  resetDevice,
                               ViString   optionString,
                               ViSession* instrSession);

ViStatus rsrth_Autoset(ViSession instrSession);

ViStatus rsrth_ConfigureMode(ViSession instrSession,
                             ViInt32   mode);

ViStatus rsrth_ConfigureAcquisitionMode(ViSession instrSession,
                                        ViInt32   acquisitionMode);

ViStatus rsrth_ConfigureNumberOfAverages(ViSession instrSession,
                                         ViInt32   numberOfAverages);

ViStatus rsrth_ConfigurePreselectedRecordLength(ViSession instrSession,
                                                ViInt32   preselectedRecordLength);

ViStatus rsrth_ConfigureWaveformUpdate(ViSession instrSession,
                                       ViInt32   waveformUpdate);

ViStatus rsrth_ConfigureAcquisitionRecord(ViSession instrSession,
                                          ViReal64  timePerRecord,
                                          ViReal64  acquisitionStartTime);

ViStatus rsrth_ConfigureAcquisitionTime(ViSession instrSession,
                                        ViReal64  acquisitionTime);

ViStatus rsrth_ConfigureTimeBase(ViSession instrSession,
                                 ViReal64  timeScale,
                                 ViInt32   referencePoint);

ViStatus rsrth_QueryResolution(ViSession instrSession,
                               ViReal64* resolution);

ViStatus rsrth_QueryADCSampleRate(ViSession instrSession,
                                  ViReal64* samplingRateC1C4);

ViStatus rsrth_QueryRecordLength(ViSession instrSession,
                                 ViInt32*  recordLength);

ViStatus rsrth_ConfigureChannel(ViSession instrSession,
                                ViInt32   channel,
                                ViBoolean channelEnabled,
                                ViReal64  verticalRange,
                                ViReal64  verticalOffset,
                                ViInt32   verticalCoupling);

ViStatus rsrth_ConfigureChannelOffset(ViSession instrSession,
                                      ViInt32   channel,
                                      ViReal64  offset);

ViStatus rsrth_ConfigureChannelDelay(ViSession instrSession,
                                     ViInt32   channel,
                                     ViReal64  delay);

ViStatus rsrth_ConfigureChannelVerticalScale(ViSession instrSession,
                                             ViInt32   channel,
                                             ViReal64  verticalScale);

ViStatus rsrth_ConfigureChannelBandwidth(ViSession instrSession,
                                         ViInt32   channel,
                                         ViInt32   bandwidth);

ViStatus rsrth_ConfigureChannelThreshold(ViSession instrSession,
                                         ViInt32   channel,
                                         ViInt32   technology,
                                         ViReal64  userValue);

ViStatus rsrth_SearchChannelThreshold(ViSession instrSession,
                                      ViInt32   channel);

ViStatus rsrth_QueryChannelThreshold(ViSession instrSession,
                                     ViInt32   channel,
                                     ViReal64* threshold);

ViStatus rsrth_ConfigureProbeSettings(ViSession instrSession,
                                      ViInt32   channel,
                                      ViInt32   probeSettling,
                                      ViReal64  probeFactor,
                                      ViInt32   probeUnit);

ViStatus rsrth_ConfigurePolarityInvertion(ViSession instrSession,
                                          ViInt32   channel,
                                          ViInt32   polarity);

ViStatus rsrth_ConfigureTrigger(ViSession instrSession,
                                ViInt32   triggerType);

ViStatus rsrth_ConfigureTriggerMode(ViSession instrSession,
                                    ViInt32   acquisitionMode,
                                    ViInt32   triggerMode);

ViStatus rsrth_ConfigureTriggerChannelLevel(ViSession instrSession,
                                            ViInt32   triggerSource,
                                            ViReal64  triggerLevel);

ViStatus rsrth_ConfigureEdgeTriggerSource(ViSession instrSession,
                                          ViInt32   triggerSource,
                                          ViReal64  triggerLevel,
                                          ViInt32   triggerSlope);

ViStatus rsrth_ConfigureEdgeTriggerNoiseReject(ViSession instrSession,
                                               ViBoolean noiseReject);

ViStatus rsrth_ConfigureEdgeExternalTrigger(ViSession instrSession,
                                            ViReal64  triggerLevel,
                                            ViInt32   triggerSlope);

ViStatus rsrth_ConfigureRuntTriggerSource(ViSession instrSession,
                                          ViInt32   triggerSource,
                                          ViReal64  runtLowThreshold,
                                          ViReal64  runtHighThreshold,
                                          ViInt32   runtPolarity);

ViStatus rsrth_ConfigureRuntTriggerRange(ViSession instrSession,
                                         ViReal64  runtWidth,
                                         ViReal64  runtDelta,
                                         ViInt32   runtCondition);

ViStatus rsrth_ConfigureGlitchTriggerSource(ViSession instrSession,
                                            ViInt32   triggerSource,
                                            ViReal64  triggerLevel,
                                            ViReal64  glitchWidth,
                                            ViInt32   glitchPolarity,
                                            ViInt32   glitchCondition);

ViStatus rsrth_ConfigureWidthTriggerSource(ViSession instrSession,
                                           ViInt32   triggerSource,
                                           ViReal64  triggerLevel,
                                           ViReal64  width,
                                           ViReal64  widthDelta,
                                           ViInt32   widthPolarity,
                                           ViInt32   widthCondition);

ViStatus rsrth_ConfigureWindowTriggerSource(ViSession instrSession,
                                            ViInt32   triggerSource,
                                            ViReal64  windowLowerLimit,
                                            ViReal64  windowUpperLimit,
                                            ViReal64  windowWidth,
                                            ViReal64  windowDelta,
                                            ViInt32   windowCondition);

ViStatus rsrth_ConfigureWindowTriggerTimeCondition(ViSession instrSession,
                                                   ViInt32   windowTimeCondition);

ViStatus rsrth_ConfigureTimeoutTriggerSource(ViSession instrSession,
                                             ViInt32   triggerSource,
                                             ViReal64  triggerLevel,
                                             ViReal64  timeoutValue,
                                             ViInt32   timeoutCondition);

ViStatus rsrth_ConfigureIntervalTriggerSource(ViSession instrSession,
                                              ViInt32   triggerSource,
                                              ViReal64  triggerLevel,
                                              ViReal64  intervalWidth,
                                              ViReal64  intervalDelta,
                                              ViInt32   intervalPolarity,
                                              ViInt32   intervalCondition);

ViStatus rsrth_ConfigureSlewRateTriggerSource(ViSession instrSession,
                                              ViInt32   triggerSource,
                                              ViReal64  slewRateLowerLimit,
                                              ViReal64  slewRateUpperLimit,
                                              ViInt32   slewRatePolarity,
                                              ViInt32   slewRateCondition);

ViStatus rsrth_ConfigureSlewRateTriggerRange(ViSession instrSession,
                                             ViReal64  slewRate,
                                             ViReal64  slewRateDelta);

ViStatus rsrth_ConfigureData2ClockTriggerSource(ViSession instrSession,
                                                ViInt32   triggerSource,
                                                ViReal64  dataLevel,
                                                ViInt32   clockSource,
                                                ViInt32   data2ClockPolarity,
                                                ViInt32   dataSource,
                                                ViInt32   triggerOnSetup,
                                                ViReal64  holdTime,
                                                ViReal64  setupTime);

ViStatus rsrth_ConfigurePatternTriggerSource(ViSession instrSession,
                                             ViReal64  timeout,
                                             ViReal64  patternWidth,
                                             ViReal64  patternDelta,
                                             ViInt32   patternCondition,
                                             ViInt32   combination,
                                             ViInt32   state);

ViStatus rsrth_ConfigureSerialPatternTriggerSource(ViSession instrSession,
                                                   ViInt32   triggerSource,
                                                   ViReal64  dataLevel,
                                                   ViInt32   clockSource,
                                                   ViInt32   dataSource,
                                                   ViString  pattern,
                                                   ViInt32   patternPolarity,
                                                   ViInt32   firstPolarity,
                                                   ViInt32   bitOrder);

ViStatus rsrth_ConfigureStateTrigger(ViSession instrSession,
                                     ViInt32   triggerSource,
                                     ViReal64  dataLevel,
                                     ViInt32   state,
                                     ViInt32   clockSource,
                                     ViInt32   combination,
                                     ViInt32   slope);

ViStatus rsrth_ConfigureTVTrigger(ViSession instrSession,
                                  ViInt32   triggerSource,
                                  ViInt32   standard,
                                  ViInt32   mode,
                                  ViInt32   lineNumber,
                                  ViInt32   lineField,
                                  ViReal64  triggerLevel,
                                  ViInt32   signalPolarity);

ViStatus rsrth_ConfigureTVTriggerCustomSettings(ViSession instrSession,
                                                ViInt32   pulseType,
                                                ViReal64  linePeriod,
                                                ViReal64  pulseWidth,
                                                ViInt32   scanMode);

ViStatus rsrth_ConfigureAOnlyTriggerSequence(ViSession instrSession,
                                             ViInt32   holdoffMode,
                                             ViReal64  holdoffTime,
                                             ViInt32   holdoffEvents,
                                             ViReal64  randomMinTime,
                                             ViReal64  randomMaxTime);

ViStatus rsrth_ConfigureDisplay(ViSession instrSession,
                                ViBoolean contrastMode,
                                ViBoolean LCDEnabled,
                                ViBoolean touchScreenEnabled);

ViStatus rsrth_ConfigurePersistence(ViSession instrSession,
                                    ViInt32   type,
                                    ViReal64  time);

ViStatus rsrth_ConfigureZoom(ViSession instrSession,
                             ViBoolean enabled,
                             ViReal64  scale,
                             ViReal64  position);

ViStatus rsrth_ConfigureHistoryState(ViSession instrSession,
                                     ViInt32   channel,
                                     ViBoolean enableHistory);

ViStatus rsrth_ConfigureHistoryStartStop(ViSession instrSession,
                                         ViInt32   channel,
                                         ViInt32   start,
                                         ViInt32   stop);

ViStatus rsrth_ConfigureHistoryAcquisitionView(ViSession instrSession,
                                               ViInt32   channel,
                                               ViInt32   acquisition);

ViStatus rsrth_ConfigureHistoryPlayerSpeed(ViSession instrSession,
                                           ViInt32   channel,
                                           ViInt32   playerSpeed);

ViStatus rsrth_ConfigureHistoryAutoRepeat(ViSession instrSession,
                                          ViInt32   channel,
                                          ViBoolean autoRepeat);

ViStatus rsrth_ConfigureHistoryNumberofSegments(ViSession instrSession,
                                                ViInt32   channel,
                                                ViInt32   numberOfSegments);

ViStatus rsrth_HistoryPlaybackControl(ViSession instrSession,
                                      ViInt32   channel);

ViStatus rsrth_QueryHistoryTimeStamp(ViSession instrSession,
                                     ViInt32   channel,
                                     ViInt32   mode,
                                     ViInt32   bufferSize,
                                     ViChar    timeStamp[]);

ViStatus rsrth_QueryHistoryDate(ViSession instrSession,
                                ViInt32   channel,
                                ViInt32   bufferSize,
                                ViChar    date[]);

ViStatus rsrth_QueryHistoryAcquisitionsCount(ViSession instrSession,
                                             ViInt32*  count);

ViStatus rsrth_ConfigureMeasurementState(ViSession instrSession,
                                         ViInt32   measurement,
                                         ViBoolean measurementState);

ViStatus rsrth_DisableAllMeasurements(ViSession instrSession);

ViStatus rsrth_ConfigureMeasurementSource(ViSession instrSession,
                                          ViInt32   measurement,
                                          ViInt32   signalSource,
                                          ViInt32   signalSource2);

ViStatus rsrth_ConfigureMeasurement(ViSession instrSession,
                                    ViInt32   measurement,
                                    ViInt32   delaySlope,
                                    ViInt32   type);

ViStatus rsrth_ConfigureCursorMeasurementType(ViSession instrSession,
                                              ViInt32   measurement,
                                              ViInt32   type);

ViStatus rsrth_ConfigureCursor(ViSession instrSession,
                               ViBoolean cursorEnabled,
                               ViInt32   dataSource,
                               ViInt32   type);

ViStatus rsrth_ConfigureCursorPosition(ViSession instrSession,
                                       ViReal64  xPosition1,
                                       ViReal64  xPosition2,
                                       ViReal64  yPosition1,
                                       ViReal64  yPosition2);

ViStatus rsrth_ConfigureCursorCoupling(ViSession instrSession,
                                       ViBoolean coupling,
                                       ViBoolean scaleCoupling);

ViStatus rsrth_CursorSetToScreen(ViSession instrSession);

ViStatus rsrth_QueryActualRecordLength(ViSession instrSession,
                                       ViInt32*  actualRecordLength);

ViStatus rsrth_QueryActualSampleMode(ViSession instrSession,
                                     ViInt32*  sampleMode);

ViStatus rsrth_ConfigureI2CTriggerType(ViSession instrSession,
                                       ViInt32   type);

ViStatus rsrth_ConfigureI2CTriggerAddress(ViSession instrSession,
                                          ViInt32   RWBitAddress,
                                          ViInt32   condition,
                                          ViString  address);

ViStatus rsrth_ConfigureI2CTriggerData(ViSession instrSession,
                                       ViInt32   condition,
                                       ViString  pattern);

ViStatus rsrth_ConfigureI2CTriggerNoAck(ViSession instrSession,
                                        ViBoolean addressNack,
                                        ViBoolean dataWriteNack,
                                        ViBoolean dataReadNack);

ViStatus rsrth_ConfigureSPITriggerType(ViSession instrSession,
                                       ViInt32   type);

ViStatus rsrth_ConfigureSPITriggerData(ViSession instrSession,
                                       ViInt32   condition,
                                       ViInt32   position,
                                       ViString  pattern,
                                       ViInt32   line);

ViStatus rsrth_ConfigureUARTTriggerType(ViSession instrSession,
                                        ViInt32   type);

ViStatus rsrth_ConfigureUARTTriggerData(ViSession instrSession,
                                        ViInt32   condition,
                                        ViString  pattern);

ViStatus rsrth_ConfigureLINTriggerType(ViSession instrSession,
                                       ViInt32   type);

ViStatus rsrth_ConfigureLINTriggerID(ViSession instrSession,
                                     ViInt32   condition,
                                     ViString  pattern);

ViStatus rsrth_ConfigureLINTriggerData(ViSession instrSession,
                                       ViInt32   condition,
                                       ViString  pattern);

ViStatus rsrth_ConfigureLINTriggerErrorConditions(ViSession instrSession,
                                                  ViBoolean checksum,
                                                  ViBoolean IDParityError,
                                                  ViBoolean syncError);

ViStatus rsrth_ConfigureCANTriggerType(ViSession instrSession,
                                       ViInt32   type,
                                       ViInt32   frameType);

ViStatus rsrth_ConfigureCANTriggerFDBits(ViSession instrSession,
                                         ViInt32   FDF,
                                         ViInt32   BRS,
                                         ViInt32   ESI);

ViStatus rsrth_ConfigureCANTriggerID(ViSession instrSession,
                                     ViInt32   type,
                                     ViInt32   condition,
                                     ViString  pattern);

ViStatus rsrth_ConfigureCANTriggerData(ViSession instrSession,
                                       ViInt32   condition,
                                       ViString  pattern);

ViStatus rsrth_ConfigureCANTriggerByteOffset(ViSession instrSession,
                                             ViInt32   byteOffset);

ViStatus rsrth_ConfigureCANTriggerErrorConditions(ViSession instrSession,
                                                  ViBoolean CRC,
                                                  ViBoolean stuffing,
                                                  ViBoolean form,
                                                  ViBoolean ack);

ViStatus rsrth_ConfigureCANTriggerStuffCountError(ViSession instrSession,
                                                  ViBoolean stuffCountError);

ViStatus rsrth_ConfigureSENTTriggerType(ViSession instrSession,
                                        ViInt32   type);

ViStatus rsrth_ConfigureSENTTriggerData(ViSession instrSession,
                                        ViInt32   condition,
                                        ViString  pattern);

ViStatus rsrth_ConfigureSENTTriggerID(ViSession instrSession,
                                      ViInt32   condition,
                                      ViString  pattern);

ViStatus rsrth_ConfigureSENTTriggerStatus(ViSession instrSession,
                                          ViInt32   condition,
                                          ViString  pattern);

ViStatus rsrth_ConfigureSENTTriggerErrorConditions(ViSession instrSession,
                                                   ViBoolean fastCRCError,
                                                   ViBoolean slowCRCError,
                                                   ViBoolean frameLengthError,
                                                   ViBoolean pulsePeriodError,
                                                   ViBoolean syncPulseError);

ViStatus rsrth_HardcopySetFileName(ViSession instrSession,
                                   ViString  name);

ViStatus rsrth_HardcopyPrint(ViSession instrSession);

ViStatus rsrth_ConfigureHardcopyDevice(ViSession instrSession,
                                       ViBoolean bW,
                                       ViInt32   destination);

ViStatus rsrth_ConfigureHardcopyInverse(ViSession instrSession,
                                        ViBoolean hardcopyInverse);

ViStatus rsrth_ConfigureLogicAnalyzer(ViSession instrSession,
                                      ViBoolean enabled,
                                      ViBoolean coupling);

ViStatus rsrth_ConfigureLogicAnalyzerChannel(ViSession instrSession,
                                             ViInt32   channel,
                                             ViReal64  deskew);

ViStatus rsrth_ConfigureLogicGroup(ViSession instrSession,
                                   ViInt32   group,
                                   ViInt32   threshold,
                                   ViReal64  userThreshold,
                                   ViInt32   hysteresis);

ViStatus rsrth_QueryLogicGroupThreshold(ViSession instrSession,
                                        ViInt32   group,
                                        ViReal64* threshold);

ViStatus rsrth_QueryLogicProbeState(ViSession  instrSession,
                                    ViBoolean* probeState);

ViStatus rsrth_ConfigureMaskTest(ViSession instrSession,
                                 ViInt32   channel,
                                 ViBoolean enabled,
                                 ViReal64  widthX,
                                 ViReal64  widthY,
                                 ViInt32   actionOnViolation);

ViStatus rsrth_CreateMaskTest(ViSession instrSession,
                              ViInt32   channel);

ViStatus rsrth_SetAttributeViInt32(ViSession instrSession,
                                   ViString  channelName,
                                   ViAttr    attributeID,
                                   ViInt32   attributeValue);

ViStatus rsrth_SetAttributeViInt64(ViSession instrSession,
                                   ViString  channelName,
                                   ViAttr    attributeID,
                                   ViInt64   attributeValue);

ViStatus rsrth_SetAttributeViReal64(ViSession instrSession,
                                    ViString  channelName,
                                    ViAttr    attributeID,
                                    ViReal64  attributeValue);

ViStatus rsrth_SetAttributeViString(ViSession instrSession,
                                    ViString  channelName,
                                    ViAttr    attributeID,
                                    ViString  attributeValue);

ViStatus rsrth_SetAttributeViBoolean(ViSession instrSession,
                                     ViString  channelName,
                                     ViAttr    attributeID,
                                     ViBoolean attributeValue);

ViStatus rsrth_GetAttributeViInt32(ViSession instrSession,
                                   ViString  channelName,
                                   ViAttr    attributeID,
                                   ViInt32*  attributeValue);

ViStatus rsrth_GetAttributeViInt64(ViSession instrSession,
                                   ViString  channelName,
                                   ViAttr    attributeID,
                                   ViInt64*  attributeValue);

ViStatus rsrth_GetAttributeViReal64(ViSession instrSession,
                                    ViString  channelName,
                                    ViAttr    attributeID,
                                    ViReal64* attributeValue);

ViStatus rsrth_GetAttributeViString(ViSession instrSession,
                                    ViString  channelName,
                                    ViAttr    attributeID,
                                    ViInt32   bufferSize,
                                    ViChar    attributeValue[]);

ViStatus rsrth_GetAttributeViBoolean(ViSession  instrSession,
                                     ViString   channelName,
                                     ViAttr     attributeID,
                                     ViBoolean* attributeValue);

ViStatus rsrth_GetAttributeRepCapName(ViSession instrSession,
                                      ViUInt32  attributeID,
                                      ViString  repcapNameID,
                                      ViInt32   index,
                                      ViInt32   bufferSize,
                                      ViChar    repcapname[]);

ViStatus rsrth_GetAttributeRepeatedCapabilityIds(ViSession instrSession,
                                                 ViUInt32  attributeID,
                                                 ViInt32   bufferSize,
                                                 ViChar    repeatedCapabilityIds[]);

ViStatus rsrth_GetAttributeRepeatedCapabilityIdNames(ViSession instrSession,
                                                     ViUInt32  attributeID,
                                                     ViString  repeatedCapabilityId,
                                                     ViInt32   bufferSize,
                                                     ViChar    repeatedCapabilityIdNames[]);

ViStatus rsrth_ConfigureMathEnabled(ViSession instrSession,
                                    ViBoolean mathEnabled);

ViStatus rsrth_ConfigureMathExpression(ViSession instrSession,
                                       ViString  expression);

ViStatus rsrth_ConfigureMathVerticalRange(ViSession instrSession,
                                          ViReal64  verticalRange);

ViStatus rsrth_ConfigureMathVerticalScale(ViSession instrSession,
                                          ViReal64  verticalScale);

ViStatus rsrth_ConfigureMathVerticalPosition(ViSession instrSession,
                                             ViReal64  verticalPosition);

ViStatus rsrth_MathReset(ViSession instrSession);

ViStatus rsrth_ConfigureReferenceWaveformSource(ViSession instrSession,
                                                ViInt32   source);

ViStatus rsrth_UpdateReferenceWaveformWithSelectedSource(ViSession instrSession);

ViStatus rsrth_ConfigureReferenceWaveformDisplayState(ViSession instrSession,
                                                      ViBoolean displayEnabled);

ViStatus rsrth_ReferenceWaveformFileOperations(ViSession instrSession,
                                               ViString  waveformName,
                                               ViInt32   operation);

ViStatus rsrth_ConfigureReferenceWaveformVerticalScaling(ViSession instrSession,
                                                         ViReal64  verticalPosition);

ViStatus rsrth_FetchWaveformHeader(ViSession instrSession,
                                   ViInt32   channel,
                                   ViReal64* xStart,
                                   ViReal64* xStop,
                                   ViInt32*  recordLength,
                                   ViInt32*  valuesPerSample);

ViStatus rsrth_FetchWaveform(ViSession instrSession,
                             ViInt32   channel,
                             ViInt32   bufferSize,
                             ViChar    waveform[]);

ViStatus rsrth_ReadWaveform(ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   bufferSize,
                            ViChar    waveform[]);

ViStatus rsrth_RunWithoutWait(ViSession instrSession);

ViStatus rsrth_RunAndWait(ViSession instrSession);

ViStatus rsrth_Stop(ViSession instrSession);

ViStatus rsrth_QueryMeasurementsResults(ViSession instrSession,
                                        ViInt32   measurement,
                                        ViReal64* result,
                                        ViInt32*  limit);

ViStatus rsrth_QueryMaskTestResults(ViSession instrSession,
                                    ViInt32   channel,
                                    ViInt32*  total,
                                    ViInt32*  passed,
                                    ViReal64* passedPct,
                                    ViInt32*  failed,
                                    ViReal64* failedPct);

ViStatus rsrth_QueryMaskTestElapsedTime(ViSession instrSession,
                                        ViInt32*  duration,
                                        ViInt32*  days,
                                        ViInt32*  hours,
                                        ViInt32*  minutes,
                                        ViInt32*  seconds,
                                        ViInt32*  deciseconds);

ViStatus rsrth_QueryMaskTestState(ViSession instrSession,
                                  ViInt32*  state);

ViStatus rsrth_ResetAllMasksResults(ViSession instrSession);

ViStatus rsrth_QueryCursorResults(ViSession instrSession,
                                  ViInt32   measurement,
                                  ViReal64* result,
                                  ViInt32*  limit);

ViStatus rsrth_QueryCursorDistances(ViSession instrSession,
                                    ViReal64* horizontal,
                                    ViReal64* vertical,
                                    ViReal64* inverse);

ViStatus rsrth_QueryCursorAmplitude(ViSession instrSession,
                                    ViReal64* amplitude1,
                                    ViReal64* amplitude2);

ViStatus rsrth_reset(ViSession instrSession);

ViStatus rsrth_revision_query(ViSession instrSession,
                              ViChar    instrumentDriverRevision[],
                              ViChar    firmwareRevision[]);

ViStatus rsrth_error_query(ViSession instrSession,
                           ViInt32*  errorCode,
                           ViChar    errorMessage[]);

ViStatus rsrth_error_message(ViSession instrSession,
                             ViStatus  errorCode,
                             ViChar    errorMessage[]);

ViStatus rsrth_ByteOrder(ViSession instrSession,
                         ViInt32   byteOrder);

ViStatus rsrth_ConfigureErrorChecking(ViSession instrSession,
                                      ViBoolean optionChecking,
                                      ViBoolean rangeChecking,
                                      ViBoolean statusChecking);

ViStatus rsrth_SetOPCTimeout(ViSession instrSession,
                             ViUInt32  OPCTimeout);

ViStatus rsrth_GetOPCTimeout(ViSession instrSession,
                             ViUInt32* timeout);

ViStatus rsrth_SetVISATimeout(ViSession instrSession,
                              ViUInt32  VISATimeout);

ViStatus rsrth_GetVISATimeout(ViSession instrSession,
                              ViUInt32* VISATimeout);

ViStatus rsrth_ClearStatus(ViSession instrSession);

ViStatus rsrth_IDQueryResponse(ViSession instrSession,
                               ViChar    IDQueryResponse[]);

ViStatus rsrth_ProcessAllPreviousCommands(ViSession instrSession);

ViStatus rsrth_QueryOPC(ViSession instrSession,
                        ViInt32*  OPC);

ViStatus rsrth_SystemDate(ViSession instrSession,
                          ViInt32   day,
                          ViInt32   month,
                          ViInt32   year);

ViStatus rsrth_SystemTime(ViSession instrSession,
                          ViInt32   hours,
                          ViInt32   minutes,
                          ViInt32   seconds);

ViStatus rsrth_SystemWLANMode(ViSession instrSession,
                              ViInt32   mode);

ViStatus rsrth_ConfigureAutoSystemErrQuery(ViSession instrSession,
                                           ViBoolean autoSystErrQuery);

ViStatus rsrth_ConfigureMultiThreadLocking(ViSession instrSession,
                                           ViBoolean multiThreadLocking);

ViStatus rsrth_ConfigureAttributeDataTypeMismatchReporting(ViSession instrSession,
                                                           ViBoolean state);

ViStatus rsrth_GetError(ViSession instrSession,
                        ViStatus* code,
                        ViInt32   bufferSize,
                        ViChar    description[]);

ViStatus rsrth_ClearError(ViSession instrSession);

ViStatus rsrth_WriteInstrData(ViSession instrSession,
                              ViString  writeBuffer);

ViStatus rsrth_QueryViBoolean(ViSession  instrSession,
                              ViString   command,
                              ViBoolean* value);

ViStatus rsrth_QueryViInt32(ViSession instrSession,
                            ViString  command,
                            ViInt32*  value);

ViStatus rsrth_QueryViReal64(ViSession instrSession,
                             ViString  command,
                             ViReal64* value);

ViStatus rsrth_QueryViString(ViSession instrSession,
                             ViString  command,
                             ViInt32   bufferSize,
                             ViChar    value[]);

ViStatus rsrth_WriteCommandWithOPCSync(ViSession instrSession,
                                       ViString  writeBuffer,
                                       ViUInt32  timeout);

ViStatus rsrth_QueryWithOPCSync(ViSession instrSession,
                                ViString  writeBuffer,
                                ViUInt32  timeout,
                                ViInt32   bufferSize,
                                ViChar    readBuffer[],
                                ViUInt32* numBytesRead);

ViStatus rsrth_FileManagerOperations(ViSession instrSession,
                                     ViInt32   operation,
                                     ViString  source,
                                     ViString  destination);

ViStatus rsrth_FileSaveInstrumentSettings(ViSession instrSession,
                                          ViString  file);

ViStatus rsrth_FileCount(ViSession instrSession,
                         ViString  directory,
                         ViInt32*  numberOfFilesAndFolders);

ViStatus rsrth_FileDirectoryContent(ViSession instrSession,
                                    ViString  directory,
                                    ViInt32   bufferSize,
                                    ViChar    output[]);

ViStatus rsrth_FileSubdirectoriesCount(ViSession instrSession,
                                       ViString  directory,
                                       ViInt32*  numberOfSubdirectories);

ViStatus rsrth_FileSubdirectories(ViSession instrSession,
                                  ViString  directory,
                                  ViInt32   bufferSize,
                                  ViChar    output[]);

ViStatus rsrth_ReadToFileFromInstrument(ViSession instrSession,
                                        ViString  source,
                                        ViString  destination);

ViStatus rsrth_WriteFromFileToInstrument(ViSession instrSession,
                                         ViString  source,
                                         ViString  destination);

ViStatus rsrth_RecallInstrumentSettings(ViSession instrSession,
                                        ViString  settingsFile);

ViStatus rsrth_ConfigureWaveformExportMultichannel(ViSession instrSession,
                                                   ViBoolean multichannelExport);

ViStatus rsrth_ConfigureWaveformExportSource(ViSession instrSession,
                                             ViInt32   source);

ViStatus rsrth_ConfigureWaveformExportScopeDataLogging(ViSession instrSession,
                                                       ViBoolean dataLogging);

ViStatus rsrth_WaveformExportInterleavedXY(ViSession instrSession,
                                           ViBoolean interleavedXY);

ViStatus rsrth_WaveformExportFile(ViSession instrSession,
                                  ViString  file);

ViStatus rsrth_ConfigureAppPath(ViSession instrSession,
                                ViString  appPath);

ViStatus rsrth_ConfigureAppPersistence(ViSession instrSession,
                                       ViBoolean appPersistence);

ViStatus rsrth_close(ViSession instrSession);

/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/

#define RSRTH_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define RSRTH_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)
#define RSRTH_WARN_DATA_NOT_AVAILABLE      (RS_CLASS_WARN_BASE + 0x0003L)

#define RSRTH_ERROR_MARKER_NOT_ENABLED     (RS_CLASS_ERROR_BASE + 0x0003L)
#define RSRTH_ERROR_NOT_DELTA_MARKER       (RS_CLASS_ERROR_BASE + 0x0002L)
#define RSRTH_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)

#define RSRTH_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define RSRTH_WARNMSG_OVER_RANGE           "Measurement overrange"
#define RSRTH_WARNMSG_DATA_NOT_AVAILABLE   "Measurement data not available"

#define RSRTH_ERRMSG_MARKER_NOT_ENABLED    "Marker Not Enabled"
#define RSRTH_ERRMSG_NOT_DELTA_MARKER      "Not Delta Marker"
#define RSRTH_ERRMSG_MAX_TIME_EXCEEDED     "Max Time Exceeded"

#define RSRTH_ERROR_CODES_AND_MSGS \
    {RSRTH_WARN_MEASURE_UNCALIBRATED,  RSRTH_WARNMSG_MEASURE_UNCALIBRATED},\
    {RSRTH_WARN_OVER_RANGE,            RSRTH_WARNMSG_OVER_RANGE},\
    {RSRTH_WARN_DATA_NOT_AVAILABLE,    RSRTH_WARNMSG_DATA_NOT_AVAILABLE},\
    {RSRTH_ERROR_MARKER_NOT_ENABLED,   RSRTH_ERRMSG_MARKER_NOT_ENABLED},\
    {RSRTH_ERROR_NOT_DELTA_MARKER,     RSRTH_ERRMSG_NOT_DELTA_MARKER},\
    {RSRTH_ERROR_NOT_DELTA_MARKER,     RSRTH_ERRMSG_NOT_DELTA_MARKER},\
    {RSRTH_ERROR_MAX_TIME_EXCEEDED,    RSRTH_ERRMSG_MAX_TIME_EXCEEDED}

/****************************************************************************
 *---------------------------- End Include File ----------------------------*
 ****************************************************************************/

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __RSRTH_HEADER */
