/*****************************************************************************
 *------------------------ Utility  -----------------------------------------*
 *****************************************************************************/
#include <float.h>
#include <math.h>
#include "rsrth.h"

#pragma warning( disable : 4152 )

/*****************************************************************************
 * Function: rsrth_InitAttributes
 * Purpose:  This function inits attributes to the desired values if needed.
 *****************************************************************************/
ViStatus rsrth_InitAttributes(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    // - Driver Identification -
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION, 0, RSRTH_SPECIFIC_DRIVER_DESCRIPTION));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_PREFIX, 0, RSRTH_SPECIFIC_DRIVER_PREFIX));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_LOCATOR, 0, RSRTH_SPECIFIC_DRIVER_LOCATOR));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_VENDOR, 0, RSRTH_SPECIFIC_DRIVER_VENDOR));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION, 0, RSRTH_CLASS_SPEC_MAJOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION, 0, RSRTH_CLASS_SPEC_MINOR_VERSION));

    // - Driver Capabilities -
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SUPPORTED_INSTRUMENT_MODELS, 0, RSRTH_SUPPORTED_INSTRUMENT_MODELS));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_GROUP_CAPABILITIES, 0, RSRTH_GROUP_CAPABILITIES));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_FUNCTION_CAPABILITIES, 0, RSRTH_FUNCTION_CAPABILITIES));

    // - Version Info -
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MAJOR_VERSION, 0, RSRTH_MAJOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MINOR_VERSION, 0, RSRTH_MINOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MINOR_MINOR_VERSION, 0, RSRTH_MINOR_MINOR_VERSION));

    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_CLASS_DRIVER_MAJOR_VERSION, 0, RSRTH_CLASS_SPEC_MAJOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_CLASS_DRIVER_MINOR_VERSION, 0, RSRTH_CLASS_SPEC_MINOR_VERSION));

    checkErr(RsCore_SetSpecificDriverRevision(instrSession, RS_ATTR_SPECIFIC_DRIVER_REVISION));

Error:
    return error;
}

/*****************************************************************************
 * Function: rsrth_DefaultInstrSetup
 * Purpose:  This function sends a default setup to the instrument. The
 *           rsrth_reset function calls this function. The
 *           rsrth_RsInit function calls this function when the
 *           user passes VI_FALSE for the reset parameter. This function is
 *           useful for configuring settings that other instrument driver
 *           functions require.
 *
 *           Note:  Call this function only when the session is locked.
 *****************************************************************************/
ViStatus rsrth_DefaultInstrSetup(ViSession instrSession)
{
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));

    // Set all the attributes to the default state. Do not update inherent attributes!
    checkErr(RsCore_ApplyAttributeDefaults(instrSession, VI_FALSE));

    // Init attributes
    checkErr(rsrth_InitAttributes(instrSession));

    rsSession->fastSweepInstrument = 0;
    checkErr(RsCore_ResetRegistersEseSre(instrSession));
    checkErr(RsCore_Write(instrSession, "*CLS"));
    checkErr(RsCore_QueryViInt32(instrSession, "*OPC?", NULL));
    checkErr(rsrth_SetAttributeViInt32(instrSession, NULL, RSRTH_ATTR_BYTE_ORDER, RSRTH_VAL_LSBF));

Error:
    return error;
}
